@filter.md:- content
title: Welcome to Pyonir
menu.group: primary
content:|
# Getting Started

This is a demo page for the Pyonir web framework.

You can edit this page by modifying the `contents/pages/index.md` file.

## Features

- Static site generation
- Flat file content management
- Plugin architecture
- Theming support


## Next Steps

- Explore the `contents` directory to add more pages and configurations.
- Create a virtual route by adding a `.routes.md` file in the `contents/pages` directory.
    - For example, visit the following links to see virtual pages in action:
    - [Virtual Pages are dope](/pyonir-developers)
- Check out the `frontend` and `backend` directories for customizing your site's appearance and functionality.
- Visit the [Pyonir documentation](https://pyonir.dev/) for more information on how to use and extend Pyonir.


**Happy coding!**

![circuts](/static/images/circuits.jpg)
![circuts](/public/city-gemini.png)
